@@ -60,6 +60,7 @@ module Test.QuickCheck
   , NonZero(..)
   , NonNegative(..)
   , Smart(..)
+  , Shrink2(..)
   , Shrinking(..)
   , ShrinkState(..)
 
@@ -94,6 +95,7 @@ module Test.QuickCheck
 
 import Test.QuickCheck.Gen
 import Test.QuickCheck.Arbitrary
+import Test.QuickCheck.Modifiers
 import Test.QuickCheck.Property hiding ( Result(..) )
 import Test.QuickCheck.Test
 import Test.QuickCheck.Text
